@@ -161,7 +161,8 @@ class VirtTests(testing.TestCase):
                  'hostname': 'host',
                  'startCpus': 2,
                  'operatingSystemReferenceCode': 'UBUNTU_LATEST',
-                 'networkComponents': [{'maxSpeed': '100'}]},)
+                 'networkComponents': [{'maxSpeed': '100'}],
+                 'supplementalCreateObjectOptions': {'bootMode': None}},)
         self.assert_called_with('SoftLayer_Virtual_Guest', 'createObject',
                                 args=args)
 
@@ -195,7 +196,8 @@ class VirtTests(testing.TestCase):
             'blockDeviceTemplateGroup': {
                 'globalIdentifier': '0B5DEAF4-643D-46CA-A695-CECBE8832C9D',
             },
-            'networkComponents': [{'maxSpeed': '100'}]
+            'networkComponents': [{'maxSpeed': '100'}],
+            'supplementalCreateObjectOptions': {'bootMode': None}
         },)
         self.assert_called_with('SoftLayer_Virtual_Guest', 'createObject',
                                 args=args)
@@ -225,7 +227,9 @@ class VirtTests(testing.TestCase):
                  'startCpus': None,
                  'maxMemory': None,
                  'localDiskFlag': None,
-                 'supplementalCreateObjectOptions': {'flavorKeyName': 'B1_1X2X25'},
+                 'supplementalCreateObjectOptions': {
+                     'bootMode': None,
+                     'flavorKeyName': 'B1_1X2X25'},
                  'operatingSystemReferenceCode': 'UBUNTU_LATEST',
                  'networkComponents': [{'maxSpeed': '100'}]},)
         self.assert_called_with('SoftLayer_Virtual_Guest', 'createObject',
@@ -261,7 +265,8 @@ class VirtTests(testing.TestCase):
                  'startCpus': 2,
                  'operatingSystemReferenceCode': 'UBUNTU_LATEST',
                  'networkComponents': [{'maxSpeed': '100'}],
-                 'dedicatedHost': {'id': 123}},)
+                 'dedicatedHost': {'id': 123},
+                 'supplementalCreateObjectOptions': {'bootMode': None}},)
         self.assert_called_with('SoftLayer_Virtual_Guest', 'createObject',
                                 args=args)
 
@@ -306,7 +311,8 @@ class VirtTests(testing.TestCase):
                  'maxMemory': 1024,
                  'localDiskFlag': False,
                  'operatingSystemReferenceCode': 'UBUNTU_LATEST',
-                 'networkComponents': [{'maxSpeed': 100}]},)
+                 'networkComponents': [{'maxSpeed': 100}],
+                 'supplementalCreateObjectOptions': {'bootMode': None}},)
         self.assert_called_with('SoftLayer_Virtual_Guest', 'createObject',
                                 args=args)
 
@@ -347,7 +353,9 @@ class VirtTests(testing.TestCase):
                  'startCpus': None,
                  'maxMemory': None,
                  'localDiskFlag': None,
-                 'supplementalCreateObjectOptions': {'flavorKeyName': 'B1_1X2X25'},
+                 'supplementalCreateObjectOptions': {
+                     'bootMode': None,
+                     'flavorKeyName': 'B1_1X2X25'},
                  'operatingSystemReferenceCode': 'UBUNTU_LATEST',
                  'networkComponents': [{'maxSpeed': 100}]},)
         self.assert_called_with('SoftLayer_Virtual_Guest', 'createObject',
@@ -606,3 +614,50 @@ class VirtTests(testing.TestCase):
             args=(100,),
             identifier=100,
         )
+
+    def test_ready(self):
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getObject')
+        mock.return_value = {
+            "provisionDate": "2017-10-17T11:21:53-07:00",
+            "id": 41957081
+        }
+        result = self.run_command(['vs', 'ready', '100'])
+        self.assert_no_fail(result)
+        self.assertEqual(result.output, '"READY"\n')
+
+    def test_not_ready(self):
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getObject')
+        not_ready = {
+            'activeTransaction': {
+                'transactionStatus': {'friendlyName': 'Attach Primary Disk'}
+            },
+            'provisionDate': '',
+            'id': 47392219
+        }
+        ready = {
+            "provisionDate": "2017-10-17T11:21:53-07:00",
+            "id": 41957081
+        }
+        mock.side_effect = [not_ready, ready]
+        result = self.run_command(['vs', 'ready', '100'])
+        self.assertEqual(result.exit_code, 2)
+        self.assertIsInstance(result.exception, exceptions.CLIAbort)
+
+    @mock.patch('time.sleep')
+    def test_going_ready(self, _sleep):
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getObject')
+        not_ready = {
+            'activeTransaction': {
+                'transactionStatus': {'friendlyName': 'Attach Primary Disk'}
+            },
+            'provisionDate': '',
+            'id': 47392219
+        }
+        ready = {
+            "provisionDate": "2017-10-17T11:21:53-07:00",
+            "id": 41957081
+        }
+        mock.side_effect = [not_ready, ready]
+        result = self.run_command(['vs', 'ready', '100', '--wait=100'])
+        self.assert_no_fail(result)
+        self.assertEqual(result.output, '"READY"\n')
